@@ -36,46 +36,6 @@
 
 G_BEGIN_DECLS
 
-typedef enum {
-  /* this enum should be renamed GeglBufferFlags, since it contains
-   * multiple flags - and possibly more in the future
-   */
-
-  /* XXX: API tidying of the following would be to make them be
-   *      GEGL_BUFFER_EDGE_NONE or GEGL_BUFFER_REPEAT_NONE instead.
-  */
-  GEGL_ABYSS_NONE  = 0,
-  GEGL_ABYSS_CLAMP = 1,
-  GEGL_ABYSS_LOOP  = 2,
-  GEGL_ABYSS_BLACK = 3,
-  GEGL_ABYSS_WHITE = 4,
-
-  GEGL_BUFFER_FILTER_AUTO     = 0,
-  /* auto gives bilinear for scales <1.0 box for <2.0 and nearest above */
-  GEGL_BUFFER_FILTER_BILINEAR = 16,
-  GEGL_BUFFER_FILTER_NEAREST  = 32,
-  GEGL_BUFFER_FILTER_BOX      = 48,
-  GEGL_BUFFER_FILTER_ALL      = (GEGL_BUFFER_FILTER_BILINEAR|
-                                 GEGL_BUFFER_FILTER_NEAREST|
-                                 GEGL_BUFFER_FILTER_BOX),
-} GeglAbyssPolicy;
-
-GType gegl_abyss_policy_get_type (void) G_GNUC_CONST;
-
-#define GEGL_TYPE_ABYSS_POLICY (gegl_abyss_policy_get_type ())
-
-
-typedef enum {
-  GEGL_ACCESS_READ      = 1 << 0,
-  GEGL_ACCESS_WRITE     = 1 << 1,
-  GEGL_ACCESS_READWRITE = (GEGL_ACCESS_READ | GEGL_ACCESS_WRITE)
-} GeglAccessMode;
-
-GType gegl_access_mode_get_type (void) G_GNUC_CONST;
-
-#define GEGL_TYPE_ACCESS_MODE (gegl_access_mode_get_type ())
-
-
 typedef enum {
   GEGL_DITHER_NONE,
   GEGL_DITHER_FLOYD_STEINBERG,
@@ -86,6 +46,8 @@ typedef enum {
   GEGL_DITHER_ARITHMETIC_ADD_COVARIANT,
   GEGL_DITHER_ARITHMETIC_XOR,
   GEGL_DITHER_ARITHMETIC_XOR_COVARIANT,
+  GEGL_DITHER_BLUE_NOISE,
+  GEGL_DITHER_BLUE_NOISE_COVARIANT,
 } GeglDitherMethod;
 
 GType gegl_dither_method_get_type (void) G_GNUC_CONST;
@@ -113,17 +75,43 @@ GType gegl_orientation_get_type (void) G_GNUC_CONST;
 #define GEGL_TYPE_ORIENTATION (gegl_orientation_get_type ())
 
 
+enum _GeglBablVariant
+{
+  GEGL_BABL_VARIANT_FLOAT=0,
+     /* pass this one to just ensure a format is float */
+  GEGL_BABL_VARIANT_LINEAR,
+     /* Y YA RGB RGBA         */
+  GEGL_BABL_VARIANT_NONLINEAR,
+     /* Y' Y'A R'G'B' R'G'B'A */
+  GEGL_BABL_VARIANT_PERCEPTUAL,
+     /* Y~ Y~A R~G~B~ R~G~B~A */
+  GEGL_BABL_VARIANT_LINEAR_PREMULTIPLIED,
+     /* YaA RaGaBaA           */
+  GEGL_BABL_VARIANT_PERCEPTUAL_PREMULTIPLIED,
+     /* Y~aA R~aG~aB~aA       */
+  GEGL_BABL_VARIANT_LINEAR_PREMULTIPLIED_IF_ALPHA,
+     /* Y YaA RGB RaGaBaA           */
+  GEGL_BABL_VARIANT_PERCEPTUAL_PREMULTIPLIED_IF_ALPHA,
+     /* Y~ Y~aA R~G~B~A R~aG~aB~aA       */
+  GEGL_BABL_VARIANT_ALPHA
+     /* add alpha if missing keep as premultiplied if already so  */
+};
+typedef enum _GeglBablVariant GeglBablVariant;
+
+GType gegl_babl_variant_get_type (void) G_GNUC_CONST;
+
+#define GEGL_TYPE_BABL_VARIANT (gegl_babl_variant_get_type ())
+
+
 typedef enum {
-  GEGL_SAMPLER_NEAREST,
-  GEGL_SAMPLER_LINEAR,
-  GEGL_SAMPLER_CUBIC,
-  GEGL_SAMPLER_NOHALO,
-  GEGL_SAMPLER_LOHALO
-} GeglSamplerType;
+  GEGL_CACHE_POLICY_AUTO,
+  GEGL_CACHE_POLICY_NEVER,
+  GEGL_CACHE_POLICY_ALWAYS
+} GeglCachePolicy;
 
-GType gegl_sampler_type_get_type (void) G_GNUC_CONST;
+GType gegl_cache_policy_get_type (void) G_GNUC_CONST;
 
-#define GEGL_TYPE_SAMPLER_TYPE (gegl_sampler_type_get_type ())
+#define GEGL_TYPE_CACHE_POLICY (gegl_cache_policy_get_type ())
 
 G_END_DECLS
 
