@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2003 Calvin Williamson
  *           2006 Øyvind Kolås
@@ -109,13 +109,14 @@ GeglNode    * gegl_node_new_child        (GeglNode      *parent,
  *
  * Makes a connection between the pads of two nodes.
  *
- * Returns TRUE if the connection was succesfully made.
+ * Returns TRUE if the connection was successfully made.
  */
 
 gboolean      gegl_node_connect_from     (GeglNode      *sink,
                                           const gchar   *input_pad_name,
                                           GeglNode      *source,
-                                          const gchar   *output_pad_name);
+                                          const gchar   *output_pad_name)
+G_DEPRECATED_FOR (gegl_node_connect or gegl_node_link if pads are "input" and "output");
 
 /**
  * gegl_node_connect_to:
@@ -126,12 +127,29 @@ gboolean      gegl_node_connect_from     (GeglNode      *sink,
  *
  * Makes a connection between the pads of two nodes.
  *
- * Returns TRUE if the connection was succesfully made.
+ * Returns TRUE if the connection was successfully made.
  */
 gboolean      gegl_node_connect_to       (GeglNode      *source,
                                           const gchar   *output_pad_name,
                                           GeglNode      *sink,
-                                          const gchar   *input_pad_name);
+                                          const gchar   *input_pad_name)
+G_DEPRECATED_FOR (gegl_node_connect or gegl_node_link if pads are "output" and "input");
+
+/**
+ * gegl_node_connect:
+ * @a: a node
+ * @a_pad_name: and the pad of the node we want connected.
+ * @b: another node
+ * @b_pad_name: and its pad to be connected.
+ *
+ * Makes a connection between the pads of two nodes, one pad should
+ * be a source pad the other a sink pad, order does not matter.
+ *
+ * Returns TRUE if the connection was successfully made.
+ */
+gboolean
+gegl_node_connect (GeglNode *a, const gchar*a_pad_name,
+                   GeglNode *b, const gchar*b_pad_name);
 
 
 /**
@@ -139,8 +157,7 @@ gboolean      gegl_node_connect_to       (GeglNode      *source,
  * @source: the producer of data.
  * @sink: the consumer of data.
  *
- * Synthetic sugar for linking the "output" pad of @source to the "input"
- * pad of @sink.
+ * This is equivalent to gegl_node_connect (source, "output", sink, "input");
  */
 void          gegl_node_link             (GeglNode      *source,
                                           GeglNode      *sink);
@@ -151,7 +168,7 @@ void          gegl_node_link             (GeglNode      *source,
  * @first_sink: the first consumer of data.
  * @...: NULL, or optionally more consumers followed by NULL.
  *
- * Synthetic sugar for linking a chain of nodes with "input"->"output". The
+ * Synthetic sugar for linking a chain of nodes with "output"->"input". The
  * list is NULL terminated.
  */
 void          gegl_node_link_many        (GeglNode      *source,
@@ -308,7 +325,7 @@ void          gegl_node_blit_buffer      (GeglNode            *node,
  * @sink_node: a #GeglNode without outputs.
  *
  * Render a composition. This can be used for instance on a node with a "png-save"
- * operation to render all neccesary data, and make it be written to file. This
+ * operation to render all necessary data, and make it be written to file. This
  * function wraps the usage of a GeglProcessor in a single blocking function
  * call. If you need a non-blocking operation, then make a direct use of
  * #gegl_processor_work. See #GeglProcessor.
@@ -565,6 +582,26 @@ gchar      ** gegl_node_list_input_pads  (GeglNode      *node);
  */
 gchar      ** gegl_node_list_output_pads (GeglNode      *node);
 
+/**
+ * gegl_node_get_pad_label:
+ * @node: the node we are querying
+ * @pad_name: the pad name we are looking for
+ *
+ * Returns: the display label for @pad_name.
+ */
+const gchar * gegl_node_get_pad_label    (GeglNode      *node,
+                                          const gchar   *pad_name);
+
+/**
+ * gegl_node_get_pad_description:
+ * @node: the node we are querying
+ * @pad_name: the pad name we are looking for
+ *
+ * Returns: the longer description for @pad_name.
+ */
+const gchar * gegl_node_get_pad_description (GeglNode      *node,
+                                             const gchar   *pad_name);
+
 /***
  * Binding conveniences:
  *
@@ -580,7 +617,7 @@ gchar      ** gegl_node_list_output_pads (GeglNode      *node);
  *
  * Creates a new processing node that performs the specified operation.
  * All properties of the operation will have their default values. This
- * is included as an addiiton to #gegl_node_new_child in the public API to have
+ * is included as an addition to #gegl_node_new_child in the public API to have
  * a non varargs entry point for bindings as well as sometimes simpler more
  * readable code.
  *
@@ -691,10 +728,15 @@ gboolean       gegl_node_get_passthrough (GeglNode      *node);
 void           gegl_node_set_passthrough (GeglNode      *node,
                                           gboolean       passthrough);
 
+gboolean        gegl_node_is_graph       (GeglNode *node);
 
 void       gegl_node_progress (GeglNode *node, gdouble progress, gchar *message);
 
 const char *gegl_operation_get_op_version (const gchar *op_name);
+void
+gegl_node_set_enum_as_string (GeglNode   *node,
+                              const char *key,
+                              const char *value);
 
 G_END_DECLS
 
